.. _population_concept:

=====================
Population Management
=====================

.. contents::
   :depth: 2
   :local:
   :backlinks: none

Outline
-------
 - Initialization of simulants and the dependency problem.
 - Managing access with population views.
 -
